@@ -2,12 +2,13 @@
 Model Generator for OpenSees ~ visibility
 """
 
-#                          __
-#   ____  ____ ___  ____ _/ /
-#  / __ \/ __ `__ \/ __ `/ /
-# / /_/ / / / / / / /_/ /_/
-# \____/_/ /_/ /_/\__, (_)
-#                /____/
+#
+#   _|_|      _|_|_|  _|      _|    _|_|_|
+# _|    _|  _|        _|_|  _|_|  _|
+# _|    _|    _|_|    _|  _|  _|  _|  _|_|
+# _|    _|        _|  _|      _|  _|    _|
+#   _|_|    _|_|_|    _|      _|    _|_|_|
+#
 #
 # https://github.com/ioannis-vm/OpenSees_Model_Generator
 
@@ -21,9 +22,11 @@ class ElementVisibility:
     Controls whether an element is displayed in the plots
     and whether it is defined in OpenSees or not
     """
+
     hidden_when_extruded: bool = field(default=False)
     hidden_at_line_plots: bool = field(default=False)
     skip_opensees_definition: bool = field(default=False)
+    hidden_basic_forces: bool = field(default=False)
 
 
 @dataclass
@@ -32,4 +35,5 @@ class NodeVisibility:
     Node visibility object.
     Controls whether a node is displayed in the plots
     """
+
     connected_to_zerolength: bool = field(default=False)
